How to use
==========


Include files
-------------

Include jQuery and the plugin to your website.
Add this between <head> and </head> on your site:

	<script src="PATH-TO-JQUERY/jquery.js"></script>
	<script src="PATH-TO-IMGPLAYER/jquery.imgplayer.js"></script>


Initialize
----------

Insert your page image. Like this:

	<img id="my-image" src="my-image.jpg" width="1400" height="2400">

It's important that you set the width & height attributes.

The image should be large enough to show your smallest detail areas details in a good resolution. How large your image should be depends on your idividual usage.

To initialize imgPlayer, you have to call it the usual jQuery way:

	<script type="text/javascript">
		$(document).ready(function(){
			$('img#my-image').imgplayer();
		}
	</script>


Define Detail Areas
-------------------

You have to define four values for every detail area:

The width and height of the area and the position, relative to the top and left side of the image.
You gotta pass these coordinates in an options array, for each area in this order:

	[left, top, width, height]

Here's a full example with four areas:

	$('img#your-image').imgplayer({
		frames: [
			[   0, 0, 1000, 100],
			[ 100, 0, 1234, 123],
			[ 200, 0, 1234, 123],
			[ 300, 0, 1234, 123]
		]
	});

That's all you need for a basic default setup.


Configure options
-----------------

Here's a list of all provided options you can use in this version:

	Option					Description								Default
	---------------------------------------------------------------------------
	maxHeight 				Maximum height of the frame.
	maxWidth 				Maximum width of the frame.
	startFrame	 			The first frame to load.				1
	startEffect  	 		The startup effect.	 					'fadeIn'
	onFirstLoaded			Callback, fired after the initial
							frame was loaded. Only working if no
							custom startEffect is used.
	(*) changeEffect 		'animate', 'static', or a function		'animate'
	(*) animateDuration 	The animation speed						600
	(*) animateEasing 		Animation easing style 					'swing'
	loop					After the last comes the first			true
	lock					Prevent skipping while animating		false
	autoplay				Autoplaying	true or false				false
	autoplayDelay			Autoplay speed in ms					3000
	autoplayHoverPause		Pause autoplay on mouseover				true
	showControls 			Show prev/next buttons					true
	controlsOpacity  		Opacity of the buttons					0.4
	onImageClick 			false, 'prev', 'next', 'prev-next'
							or a function to call					'prev-next'
	(*) onStart 			Function to call on skipping start
	(*) onComplete  		Function to call on skipping end

To overwrite the default settings, just add your configurations like this:

	$('img#your-image').imgplayer({
		frames: [
			[   0, 0, 1000, 100],
			[ 100, 0, 1234, 123],
			[ 200, 0, 1234, 123],
			[ 300, 0, 1234, 123]
		],
		changeEffect:  'static',
		animateEasing: 'easeOutElastic'
	});

You can set the (*) options not only global, but for single frames.
Just pass the options after the coordinates (in an object).

Like this:

	$('img#your-image').imgplayer({
		frames: [
			[   0, 0, 1000, 100, {
				changeEffect: 'static',
				animateEasing: 'easeOutElastic'
			}],
			[ 100, 0, 1234, 123, {
				changeEffect: 'animate',
				animateDuration: 200
			}]
		],
	});


Styling
-------

You can override or edit the imgplayer.css and customize the HTML output via config variables.

Defaults:

tplBackwards:

	<div class="controls">
		<a class="goto-prev prev" title="Backwards">&larr;</a>
	</div>

tplForwards:

	<div class="controls">
		<a class="goto-next next" title="Forwards">&rarr;</a>
	</div>

tplPrevNext:

	<div class="controls">
		<a class="goto-prev left" title="Backwards">&larr;</a>
		<a class="goto-next right" title="Forwards">&rarr;</a>
	</div>

tplAutoplayPause:

	<div class="controls autoplay-pause">
		<span>Autoplay paused</span>
	</div>

tplNaviBefore:

	<ul class="imgplayer-navi">

tplNaviAfter:

	</ul>


You can customize them in your imgplayer call, like this:

	$(image).imgplayer({
		tplPrevNext: '<div class="controls">
		                  <a class="goto-prev left" title="Go back!">Previous</a>
						  <a class="goto-next right" title="Go forwards!">Next</a>
					  </div>'
	});

Note that you shouldn't edit the HTML structure.



### Rounded Corners

Because of crappy browser support for 'overflow: hidden' on elements containing images imgPlayer uses a little workaround.
Set the CSS 'border-radius' on the image and the script will create a wrapping div around the image only to clip it with your border radius.

Example:

	<img src="image.jpg" style="border-radius:10px">



API
---

### Public functions

	$.imgplayer.goto()

	$.imgplayer.gotoNext()

	$.imgplayer.gotoPrev()

	$.imgplayer.gotoFirst()

	$.imgplayer.gotoFull()

	$.imgplayer.onStart()

	$.imgplayer.onComplete()

	$.imgplayer.autoplay()

	$.imgplayer.stopAutoplay()

	$.imgplayer.setOptions()



### Order of called onStart & onComplete functions:

1. Initial frames array in $(element).imgplayer
2. $.imgplayer.on*
3. $.setOptions
4. Initial options array



Feedback & Contribution
-----------------------

[Project Website](http://carlito.me/imgplayer/)

Please report bugs, share ideas	or give general feedback [here](http://imgareawalk.idea.informer.com).

Mail: c@sugarman.tv



